@@ -177,7 +177,7 @@ add_address_row (CEPageIP6   *page,
 
         row_grid = gtk_grid_new ();
         label = gtk_label_new (_("Address"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 1, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -190,7 +190,7 @@ add_address_row (CEPageIP6   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 1, 1, 1);
 
         label = gtk_label_new (_("Prefix"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 2, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -203,7 +203,7 @@ add_address_row (CEPageIP6   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 2, 1, 1);
 
         label = gtk_label_new (_("Gateway"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 3, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -345,7 +345,7 @@ add_dns_row (CEPageIP6   *page,
 
         row_box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         label = gtk_label_new (_("Server"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_box_pack_start (GTK_BOX (row_box), label, FALSE, FALSE, 0);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -441,7 +441,7 @@ add_route_row (CEPageIP6   *page,
 
         row_grid = gtk_grid_new ();
         label = gtk_label_new (_("Address"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 1, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -454,7 +454,7 @@ add_route_row (CEPageIP6   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 1, 1, 1);
 
         label = gtk_label_new (_("Prefix"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 2, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -471,7 +471,7 @@ add_route_row (CEPageIP6   *page,
         gtk_grid_attach (GTK_GRID (row_grid), widget, 2, 2, 1, 1);
 
         label = gtk_label_new (_("Gateway"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 3, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -485,7 +485,7 @@ add_route_row (CEPageIP6   *page,
 
         /* Translators: Please see https://en.wikipedia.org/wiki/Metrics_(networking) */
         label = gtk_label_new (C_("network parameters", "Metric"));
-        gtk_misc_set_alignment (GTK_MISC (label), 1, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_END);
         gtk_grid_attach (GTK_GRID (row_grid), label, 1, 4, 1, 1);
         widget = gtk_entry_new ();
         gtk_label_set_mnemonic_widget (GTK_LABEL (label), widget);
@@ -625,7 +625,6 @@ connect_ip6_page (CEPageIP6 *page)
                                            METHOD_COL_NAME, _("Link-Local Only"),
                                            METHOD_COL_METHOD, IP6_METHOD_LINK_LOCAL,
                                            -1);
-        g_object_unref (G_OBJECT (store));
 
         gtk_combo_box_set_model (page->method, GTK_TREE_MODEL (store));
 
@@ -645,7 +644,6 @@ connect_ip6_page (CEPageIP6 *page)
         page->never_default = GTK_WIDGET (gtk_builder_get_object (CE_PAGE (page)->builder, "never_default_check"));
         gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->never_default),
                                       nm_setting_ip6_config_get_never_default (page->setting));
-        g_signal_connect_swapped (page->never_default, "toggled", G_CALLBACK (ce_page_changed), page);
 
         g_signal_connect (page->method, "changed", G_CALLBACK (method_changed), page);
         if (method != IP6_METHOD_SHARED && method != IP6_METHOD_IGNORE)
@@ -683,11 +681,7 @@ ui_to_setting (CEPageIP6 *page)
         }
 
         nm_setting_ip6_config_clear_addresses (page->setting);
-        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
-        else
-                children = NULL;
-
+        children = gtk_container_get_children (GTK_CONTAINER (page->address_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -758,13 +752,7 @@ ui_to_setting (CEPageIP6 *page)
         g_list_free (children);
 
         nm_setting_ip6_config_clear_dns (page->setting);
-        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_AUTO) ||
-            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_DHCP) ||
-            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
-        else
-                children = NULL;
-
+        children = gtk_container_get_children (GTK_CONTAINER (page->dns_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
@@ -793,13 +781,7 @@ ui_to_setting (CEPageIP6 *page)
         g_list_free (children);
 
         nm_setting_ip6_config_clear_routes (page->setting);
-        if (g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_AUTO) ||
-            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_DHCP) ||
-            g_str_equal (method, NM_SETTING_IP6_CONFIG_METHOD_MANUAL))
-                children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
-        else
-                children = NULL;
-
+        children = gtk_container_get_children (GTK_CONTAINER (page->routes_list));
         for (l = children; l; l = l->next) {
                 GtkWidget *row = l->data;
                 GtkEntry *entry;
