@@ -127,7 +127,6 @@ cc_region_panel_finalize (GObject *object)
 {
 	CcRegionPanel *self = CC_REGION_PANEL (object);
 	CcRegionPanelPrivate *priv = self->priv;
-	GtkWidget *chooser;
 
         g_cancellable_cancel (priv->cancellable);
         g_clear_object (&priv->cancellable);
@@ -161,9 +160,6 @@ cc_region_panel_finalize (GObject *object)
         g_free (priv->system_language);
         g_free (priv->system_region);
 
-        chooser = g_object_get_data (G_OBJECT (self), "input-chooser");
-        gtk_widget_destroy (chooser);
-
 	G_OBJECT_CLASS (cc_region_panel_parent_class)->finalize (object);
 }
 
@@ -828,7 +824,7 @@ add_input_row (CcRegionPanel   *self,
         box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
         gtk_container_add (GTK_CONTAINER (row), box);
         label = gtk_label_new (name);
-        gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+        gtk_widget_set_halign (label, GTK_ALIGN_START);
         gtk_widget_set_margin_start (label, 20);
         gtk_widget_set_margin_end (label, 20);
         gtk_widget_set_margin_top (label, 6);
@@ -1080,31 +1076,6 @@ update_input (CcRegionPanel *self)
         }
 }
 
-static void
-apologize_for_no_ibus_login (CcRegionPanel *self)
-{
-        GtkWidget *dialog;
-        GtkWidget *toplevel;
-        GtkWidget *image;
-
-        toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-
-        dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-                                         GTK_DIALOG_MODAL | GTK_DIALOG_USE_HEADER_BAR,
-                                         GTK_MESSAGE_OTHER,
-                                         GTK_BUTTONS_OK,
-                                         _("Sorry"));
-        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                                  "%s", _("Input methods can't be used on the login screen"));
-        image = gtk_image_new_from_icon_name ("face-sad-symbolic",
-                                              GTK_ICON_SIZE_DIALOG);
-        gtk_widget_show (image);
-        gtk_message_dialog_set_image (GTK_MESSAGE_DIALOG (dialog), image);
-
-        gtk_dialog_run (GTK_DIALOG (dialog));
-        gtk_widget_destroy (dialog);
-}
-
 static gboolean
 input_source_already_added (CcRegionPanel *self,
                             const gchar   *id)
@@ -1125,14 +1096,15 @@ input_source_already_added (CcRegionPanel *self,
 }
 
 static void
-run_input_chooser (CcRegionPanel *self, GtkWidget *chooser)
+input_response (GtkWidget *chooser, gint response_id, gpointer data)
 {
+	CcRegionPanel *self = data;
         gchar *type;
         gchar *id;
         gchar *name;
         GDesktopAppInfo *app_info = NULL;
 
-        if (gtk_dialog_run (GTK_DIALOG (chooser)) == GTK_RESPONSE_OK) {
+        if (response_id == GTK_RESPONSE_OK) {
                 if (cc_input_chooser_get_selected (chooser, &type, &id, &name) &&
                     !input_source_already_added (self, id)) {
                         if (g_str_equal (type, INPUT_SOURCE_TYPE_IBUS)) {
@@ -1146,19 +1118,17 @@ run_input_chooser (CcRegionPanel *self, GtkWidget *chooser)
                                 type = INPUT_SOURCE_TYPE_XKB;
                         }
 
-                        if (self->priv->login && g_str_equal (type, INPUT_SOURCE_TYPE_IBUS)) {
-                                apologize_for_no_ibus_login (self);
-                        } else {
-                                add_input_row (self, type, id, name, app_info);
-                                update_buttons (self);
-                                update_input (self);
-                        }
+                        add_input_row (self, type, id, name, app_info);
+                        update_buttons (self);
+                        update_input (self);
+
                         g_free (id);
                         g_free (name);
                         g_clear_object (&app_info);
                 }
         }
-        gtk_widget_hide(chooser);
+        gtk_widget_destroy (chooser);
+        g_object_set_data (G_OBJECT (self), "input-chooser", NULL);
 }
 
 static void
@@ -1168,26 +1138,21 @@ show_input_chooser (CcRegionPanel *self)
         GtkWidget *chooser;
         GtkWidget *toplevel;
 
-        chooser = g_object_get_data (G_OBJECT (self), "input-chooser");
-
-        if (!chooser) {
-                toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-                chooser = cc_input_chooser_new (GTK_WINDOW (toplevel),
-                                                priv->xkb_info,
+        toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
+        chooser = cc_input_chooser_new (GTK_WINDOW (toplevel),
+                                        priv->login,
+                                        priv->xkb_info,
 #ifdef HAVE_IBUS
-                                                priv->ibus_engines
+                                        priv->ibus_engines
 #else
-                                                NULL
+                                        NULL
 #endif
-                                                );
-                g_object_ref (chooser);
-                g_object_set_data_full (G_OBJECT (self), "input-chooser",
-                                        chooser, g_object_unref);
-        } else {
-                cc_input_chooser_reset (chooser);
-        }
+                );
+        g_signal_connect (chooser, "response",
+                          G_CALLBACK (input_response), self);
+        gtk_window_present (GTK_WINDOW (chooser));
 
-        run_input_chooser (self, chooser);
+        g_object_set_data (G_OBJECT (self), "input-chooser", chooser);
 }
 
 static void
